function getSaveToken(callback) {
    chrome.storage.sync.get(['token'], function (result) {
        callback(chrome.runtime.lastError ? null : result.token);
    });
}

// 这里是接口主地址不能修改
var restUrl = "https://www.keywords.cool/api/v1/";

// 发送 http 请求的基类
class Base {
    constructor() {
        this.baseRequestUrl = restUrl;
    }
    request(token, params) {
        let url = this.baseRequestUrl + params.url;
        if (!params.type) {
            params.type = 'GET';
        }
        $.ajax({
            method: params.type,
            url: url,
            dataType: 'json',
            data: params.data,
            headers: {
                "token": token
            }
        }).done(res => {
            params.sCallback && params.sCallback(res);
        }).fail(function (jqXHR, textStatus) {
            alert("Request failed: " + textStatus);
        });
    }
}
// post get 关键词的类
class Keywords extends Base {
    constructor() {
        super();
    }

    appBGFInit(token, type, callback) {
        this.request(token, {
            url: 'keywords/by_user?page=1&type=' + type,
            sCallback: res => {
                callback && callback(res);
            }
        });
    }

    getPageMore(token, page, type, callback) {
        this.request(token, {
            url: 'keywords/by_user?page=' + page + '&type=' + type,
            sCallback: res => {
                callback && callback(res);
            }
        });
    }


    addToFavorite(token, id, callback) {
        this.request(token, {
            url: 'keywords/favorite',
            type: 'post',
            data: 'id=' + id,
            sCallback: res => {
                callback && callback(res);
            }
        });
    }
    // 从收藏移除
    removeFavorite(token, id, callback) {
        this.request(token, {
            url: 'keywords/removefavo',
            type: 'post',
            data: 'id=' + id,
            sCallback: res => {
                callback && callback(res);
            }
        });
    }

    addToDeleted(token, id, callback) {
        this.request(token, {
            url: 'keywords/delete',
            type: 'post',
            data: 'id=' + id,
            sCallback: res => {
                callback && callback(res);
            }
        });
    }

    keywordsSearch(token, search, callback) {
        this.request(token, {
            url: 'keywords/search',
            type: 'post',
            data: 'search=' + search,
            sCallback: res => {
                callback && callback(res);
            }
        });
    }

    getAmount(token, callback) {
        this.request(token, {
            url: 'user/amount',
            type: 'get',
            sCallback: res => {
                callback && callback(res);
            }
        });
    }
}


function init() {
    let words = new Keywords();
    getSaveToken((saveToken) => {
        if (saveToken) {
            words.appBGFInit(saveToken, 'baidu', res => {
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-baidu ul.tab-root").html("<li>" + res.err_msg + "</li>");
                } else {
                    console.log(res);
                    let data = res.data;
                    if (typeof data == "object" && Object.keys(data).length > 0) {
                        let dataArr = data.data;
                        let newDom = createBaiduDomList(dataArr);
                        $("#nav-baidu ul.tab-root").html(newDom);
                    } else {
                        $("#nav-baidu ul.tab-root").html("<li>暂时没有数据,请配合油猴脚本先保存数据</li>");
                    }
                }
            });
            words.appBGFInit(saveToken, 'google', res => {
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-google ul.tab-root").html("<li>" + res.err_msg + "</li>");
                } else {
                    console.log(res);
                    let data = res.data;
                    if (typeof data == "object" && Object.keys(data).length > 0) {
                        let dataArr = data.data;
                        let newDom = createGoogleDomList(dataArr);
                        $("#nav-google ul.tab-root").html(newDom);
                    } else {
                        $("#nav-google ul.tab-root").html("<li>暂时没有数据,请配合油猴脚本先保存数据</li>");
                    }
                }
            });
            words.appBGFInit(saveToken, 'favo', res => {
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-favorite ul.tab-root").html("<li>" + res.err_msg + "</li>");
                } else {
                    console.log(res);
                    let data = res.data;
                    if (typeof data == "object" && Object.keys(data).length > 0) {
                        let dataArr = data.data;
                        let newDom = createFavoriteDomList(dataArr);
                        $("#nav-favorite ul.tab-root").html(newDom);
                    } else {
                        $("#nav-favorite ul.tab-root").html("<li>暂时没有数据,请配合油猴脚本先保存数据</li>");
                    }
                }
            });
            words.getAmount(saveToken, res => {
                console.log(res);
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-amount ul.tab-root").html("<li>" + res.err_msg + "</li>");
                } else {
                    $("#nav-amount ul.tab-root").html("<li>您账号是：" + res.account + "</li>" +
                        "<li>您还剩：" + res.amount + "条</li>" +
                        "<li>您还剩：" + res.expire_time + "到期</li>");
                }
            });
        }
    });
}

init();

function createBaiduDomList(dataArr) {
    let domStr = "";
    dataArr.forEach(function (item) {
        if (item.favorite == 2) {
            domStr += `<li>
                <div><a href="https://www.baidu.com/s?wd=${item.keywords}" target="_blank">${item.keywords}</a></div>
                <div class="down-row">
                    <div class="create-time">${item.create_time}</div>
                    <div class="right-cont" data-id="${item.id}"><a href="#" class="my-favo"><img src="images/favo16.png" alt=""></a><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                </div>
            </li>`;
        } else {
            domStr += `<li>
                <div><a href="https://www.baidu.com/s?wd=${item.keywords}" target="_blank">${item.keywords}</a></div>
                <div class="down-row">
                    <div class="create-time">${item.create_time}</div>
                    <div class="right-cont" data-id="${item.id}"><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                </div>
            </li>`;
        }
    });
    return domStr;
}

function createGoogleDomList(dataArr) {
    let domStr = "";
    dataArr.forEach(function (item) {
        if (item.favorite == 2) {
            domStr += `<li>
                <div><a href="https://www.google.com/search?q=${item.keywords}" target="_blank">${item.keywords}</a></div>
                <div class="down-row">
                    <div class="create-time">${item.create_time}</div>
                    <div class="right-cont" data-id="${item.id}"><a href="#" class="my-favo"><img src="images/favo16.png" alt=""></a><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                </div>
            </li>`;
        } else {
            domStr += `<li>
                <div><a href="https://www.google.com/search?q=${item.keywords}" target="_blank">${item.keywords}</a></div>
                <div class="down-row">
                    <div class="create-time">${item.create_time}</div>
                    <div class="right-cont" data-id="${item.id}"><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                </div>
            </li>`;
        }
    });
    return domStr;
}

function createFavoriteDomList(dataArr) {
    let domStr = "";
    dataArr.forEach(function (item) {
        if (item.type == 'baidu') {
            domStr += `<li>
                <div><a href="https://www.baidu.com/s?wd=${item.keywords}" target="_blank">${item.keywords}</a></div>
                <div class="down-row">
                    <div class="create-time">${item.create_time}</div>
                    <div class="search-type">百度</div>
                    <div class="right-cont" data-id="${item.id}"><a href="#" class="remove-my-favo"><img src="images/unlike2_16.png" alt=""></a><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                </div>
            </li>`;
        } else {
            domStr += `<li>
                <div><a href="https://www.google.com/search?q=${item.keywords}" target="_blank">${item.keywords}</a></div>
                <div class="down-row">
                    <div class="create-time">${item.create_time}</div>
                    <div class="search-type color-g">谷歌</div>
                    <div class="right-cont" data-id="${item.id}"><a href="#" class="remove-my-favo"><img src="images/unlike2_16.png" alt=""></a><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                </div>
            </li>`;
        }
    });
    return domStr;
}

function createSearchDomList(dataArr) {
    let domStr = "";
    dataArr.forEach(function (item) {
        if (item.type == 'baidu') {
            if (item.favorite == 2) {
                domStr += `<li>
                    <div><a href="https://www.baidu.com/s?wd=${item.keywords}" target="_blank">${item.keywords}</a></div>
                    <div class="down-row">
                        <div class="create-time">${item.create_time}</div>
                        <div class="search-type">百度</div>
                        <div class="right-cont" data-id="${item.id}"><a href="#" class="my-favo"><img src="images/favo16.png" alt=""></a><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                    </div>
                </li>`;
            } else {
                domStr += `<li>
                    <div><a href="https://www.baidu.com/s?wd=${item.keywords}" target="_blank">${item.keywords}</a></div>
                    <div class="down-row">
                        <div class="create-time">${item.create_time}</div>
                        <div class="search-type">百度</div>
                        <div class="right-cont" data-id="${item.id}"><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                    </div>
                </li>`;
            }
        } else {
            if (item.favorite == 2) {
                domStr += `<li>
                    <div><a href="https://www.google.com/search?q=${item.keywords}" target="_blank">${item.keywords}</a></div>
                    <div class="down-row">
                        <div class="create-time">${item.create_time}</div>
                        <div class="search-type color-g">谷歌</div>
                        <div class="right-cont" data-id="${item.id}"><a href="#" class="my-favo"><img src="images/favo16.png" alt=""></a><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                    </div>
                </li>`;
            } else {
                domStr += `<li>
                    <div><a href="https://www.google.com/search?q=${item.keywords}" target="_blank">${item.keywords}</a></div>
                    <div class="down-row">
                        <div class="create-time">${item.create_time}</div>
                        <div class="search-type color-g">谷歌</div>
                        <div class="right-cont" data-id="${item.id}"><a href="#" class="my-del"><img src="images/trash16.png" alt=""></a></div>
                    </div>
                </li>`;
            }
        }
    });
    return domStr;
}

// 翻页加载更多事件处理
var baiduPage = 1;
$("#load-baidu-more").on("click", function () {
    baiduPage++
    let words = new Keywords();
    getSaveToken((saveToken) => {
        if (saveToken) {
            words.getPageMore(saveToken, baiduPage, 'baidu', res => {
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-baidu ul.tab-root").html("<li>" + res.err_msg + "</li>");
                } else {
                    console.log(res);
                    let data = res.data;
                    if (typeof data == "object" && Object.keys(data).length > 0) {
                        let dataArr = data.data;
                        let newDom = createBaiduDomList(dataArr);
                        $("#nav-baidu ul.tab-root").append(newDom);
                    } else {
                        $("#nav-baidu ul.tab-root").append("<li>没有数据了，己到底</li>");
                        $(this).attr("disabled", 'disabled');
                    }
                }
            });
        }
    });
});
var googlePage = 1;
$("#load-google-more").on("click", function () {
    googlePage++
    let words = new Keywords();
    getSaveToken((saveToken) => {
        if (saveToken) {
            words.getPageMore(saveToken, googlePage, 'google', res => {
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-google ul.tab-root").html("<li>" + res.err_msg + "</li>");
                } else {
                    console.log(res);
                    let data = res.data;
                    if (typeof data == "object" && Object.keys(data).length > 0) {
                        let dataArr = data.data;
                        let newDom = createGoogleDomList(dataArr);
                        $("#nav-google ul.tab-root").append(newDom);
                    } else {
                        $("#nav-google ul.tab-root").append("<li>没有数据了，己到底</li>");
                        $(this).attr("disabled", 'disabled');
                    }
                }
            });
        }
    });
});
var favoPage = 1;
$("#load-favo-more").on("click", function () {
    favoPage++
    let words = new Keywords();
    getSaveToken((saveToken) => {
        if (saveToken) {
            words.getPageMore(saveToken, favoPage, 'favo', res => {
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-favorite ul.tab-root").html("<li>" + res.err_msg + "</li>");
                } else {
                    console.log(res);
                    let data = res.data;
                    if (typeof data == "object" && Object.keys(data).length > 0) {
                        let dataArr = data.data;
                        let newDom = createFavoriteDomList(dataArr);
                        $("#nav-favorite ul.tab-root").append(newDom);
                    } else {
                        $("#nav-favorite ul.tab-root").append("<li>没有数据了，己到底</li>");
                        $(this).attr("disabled", 'disabled');
                    }
                }
            });
        }
    });
});
// 收藏
$("ul.tab-root").on("click", ".my-favo", function (e) {
    let id = $(this).parent().data("id");
    let words = new Keywords();
    getSaveToken((saveToken) => {
        if (saveToken) {
            words.addToFavorite(saveToken, id, res => {
                layer.alert(res.err_msg);
                $(this).remove();
            });
        }
    });
});
// 删除
$("ul.tab-root").on("click", ".my-del", function (e) {
    let id = $(this).parent().data("id");
    let _this = $(this);
    layer.confirm('确定要删除吗？', {
        btn: ['删除', '再想一想'] //按钮
    }, function () {
        let words = new Keywords();
        getSaveToken((saveToken) => {
            if (saveToken) {
                words.addToDeleted(saveToken, id, res => {
                    layer.alert(res.err_msg);
                    _this.parent().parent().parent().remove();
                });
            }
        });
        layer.msg('己删除', { icon: 1 });
    }, function () {
        layer.msg('您己经取消删除', { icon: 2 });
    });

});
// 移出收藏
$("ul.tab-root").on("click", ".remove-my-favo", function (e) {
    let id = $(this).parent().data("id");
    let _this = $(this);
    layer.confirm('确定要移出收藏吗？', {
        btn: ['移除', '再想一想'] //按钮
    }, function () {
        let words = new Keywords();
        getSaveToken((saveToken) => {
            if (saveToken) {
                words.removeFavorite(saveToken, id, res => {
                    layer.alert(res.err_msg);
                    _this.parent().parent().parent().remove();
                });
            }
        });
        layer.msg('己移除', { icon: 1 });
    }, function () {
        layer.msg('您己经取消移除', { icon: 2 });
    });

});

// 搜索
$("#search-btn").on('click', function () {
    let search = $("#search").val();
    if (search == '') {
        layer.alert("请填写关键词");
        return;
    }
    let words = new Keywords();
    getSaveToken((saveToken) => {
        if (saveToken) {
            words.keywordsSearch(saveToken, search, res => {
                if (res && res.err_code && res.err_code > 10000) {
                    $("#nav-search ul.tab-root").html("<li>" + res.err_msg + "</li>");
                    $('#nav-tab a:nth-child(4)').tab('show');
                } else {
                    let data = res;
                    let newDom = createSearchDomList(data);
                    $("#nav-search ul.tab-root").html(newDom);
                    $('#nav-tab a:nth-child(4)').tab('show');
                }
            });
        }
    });
});

// 回车键 点击查询按钮
$(document).bind('keyup', function (e) {
    if (event.keyCode == 13) {
        $("#search-btn").click();
    }
});



